@@ -5,7 +5,7 @@ import sys
 import io
 from inspect import isfunction
 
-from wcs.commons.logme import debug,error,warning
+#from wcs.commons.logme import debug,error,warning
 
 class Config(object):
     _instance = None
@@ -74,6 +74,10 @@ class Config(object):
     detectNotifyRule = ''
     hashAlgorithm = ''
 
+    #是否打印日志，默认debug
+    log_level = 10
+
+
     ## Creating a singleton
     def __new__(self, configfile=None, ak=None, sk=None, put_url=None, mgr_url=None ):
         if self._instance == None:
@@ -85,8 +89,8 @@ class Config(object):
             try:
                 self.read_config_file(configfile)
             except IOError as e:  # 这里尚未确定读取配置文件异常如何处理
-                error("Can't read config file ")
-                sys.exit()
+                raise ("Can't read config file ")
+                #sys.exit()
 
     def option_list(self):
         retval = []
@@ -156,7 +160,7 @@ class ConfigParser(object):
                         try: #caiyz 20180315 添加异常处理
                             print_value = ("%s...%d_chars...%s") % (data["value"][-2], len(data["value"]) - 3, data["value"][-1:1])
                         except IndexError as e:
-                            debug(u"{} is empty".format(data["key"]))
+                            raise (u"{} is empty".format(data["key"]))
                     else:
                         print_value = data["value"]
                     #debug("ConfigParser: %s->%s" % (data["key"], print_value))
